@@ -21,10 +21,10 @@ class User(BaseModel):
 
 class Note(BaseModel):
     user = ForeignKeyField(User)
-    text = TextField()
+    text = TextField(index=True)
 
 class Category(BaseModel):
-    name = CharField()
+    name = CharField(unique=True)
     parent = ForeignKeyField('self', null=True)
 
 class capture_output(object):
@@ -50,20 +50,20 @@ class BaseModel(Model):
         database = database
 
 class Category(BaseModel):
-    name = CharField(max_length=255)
+    name = CharField(unique=True)
     parent = ForeignKeyField(db_column='parent_id', null=True, rel_model='self', to_field='id')
 
     class Meta:
         db_table = 'category'
 
 class User(BaseModel):
-    username = CharField(max_length=255, primary_key=True)
+    username = CharField(primary_key=True)
 
     class Meta:
         db_table = 'user'
 
 class Note(BaseModel):
-    text = TextField()
+    text = TextField(index=True)
     user = ForeignKeyField(db_column='user_id', rel_model=User, to_field='username')
 
     class Meta:
