@@ -29,7 +29,7 @@ class BaseModel(Model):
         database = sqlite_db
 
 class ColTypes(BaseModel):
-    f1 = BigIntegerField()
+    f1 = BigIntegerField(index=True)
     f2 = BlobField()
     f3 = BooleanField()
     f4 = CharField(max_length=50)
@@ -38,11 +38,17 @@ class ColTypes(BaseModel):
     f7 = DecimalField()
     f8 = DoubleField()
     f9 = FloatField()
-    f10 = IntegerField()
+    f10 = IntegerField(unique=True)
     f11 = PrimaryKeyField()
     f12 = TextField()
     f13 = TimeField()
 
+    class Meta:
+        indexes = (
+            (('f10', 'f11'), True),
+            (('f11', 'f12', 'f13'), False),
+        )
+
 class Nullable(BaseModel):
     nullable_cf = CharField(null=True)
     nullable_if = IntegerField(null=True)
@@ -135,6 +141,42 @@ class TestReflection(unittest.TestCase):
         self.assertEqual(relmodel.col_types_nullable.rel_model,
                          models['coltypes'])
 
+    def test_generate_models_indexes(self):
+        introspector = self.get_introspector()
+        self.assertEqual(introspector.generate_models(), {})
+
+        for model in MODELS:
+            model.create_table()
+
+        models = introspector.generate_models()
+
+        self.assertEqual(models['fkpk']._meta.indexes, [])
+        self.assertEqual(models['relmodel']._meta.indexes, [])
+        self.assertEqual(models['category']._meta.indexes, [])
+
+        col_types = models['coltypes']
+        indexed = set(['f1'])
+        unique = set(['f10'])
+        for field in col_types._meta.get_fields():
+            self.assertEqual(field.index, field.name in indexed)
+            self.assertEqual(field.unique, field.name in unique)
+        indexes = col_types._meta.indexes
+        self.assertEqual(sorted(indexes), [
+            (['f10', 'f11'], True),
+            (['f11', 'f12', 'f13'], False),
+        ])
+
+    def test_table_subset(self):
+        for model in MODELS:
+            model.create_table()
+
+        introspector = self.get_introspector()
+        models = introspector.generate_models(table_names=[
+            'category',
+            'coltypes',
+            'foobarbaz'])
+        self.assertEqual(sorted(models.keys()), ['category', 'coltypes'])
+
     def test_sqlite_fk_re(self):
         user_id_tests = [
             'FOREIGN KEY("user_id") REFERENCES "users"("id")',
@@ -216,7 +258,7 @@ class TestReflection(unittest.TestCase):
 
     @generative_test
     def test_col_types(self, introspector):
-        columns, primary_keys, foreign_keys, model_names =\
+        columns, primary_keys, foreign_keys, model_names, indexes =\
                 introspector.introspect()
 
         expected = (
@@ -262,7 +304,7 @@ class TestReflection(unittest.TestCase):
 
     @generative_test
     def test_foreign_keys(self, introspector):
-        columns, primary_keys, foreign_keys, model_names =\
+        columns, primary_keys, foreign_keys, model_names, indexes =\
                 introspector.introspect()
 
         self.assertEqual(foreign_keys['coltypes'], [])
@@ -290,7 +332,7 @@ class TestReflection(unittest.TestCase):
 
     @generative_test
     def test_table_names(self, introspector):
-        columns, primary_keys, foreign_keys, model_names =\
+        columns, primary_keys, foreign_keys, model_names, indexes =\
                 introspector.introspect()
 
         names = (
@@ -303,7 +345,7 @@ class TestReflection(unittest.TestCase):
 
     @generative_test
     def test_column_meta(self, introspector):
-        columns, primary_keys, foreign_keys, model_names =\
+        columns, primary_keys, foreign_keys, model_names, indexes =\
                 introspector.introspect()
 
         rel_model = columns['relmodel']
@@ -342,25 +384,25 @@ class TestReflection(unittest.TestCase):
 
     @generative_test
     def test_get_field(self, introspector):
-        columns, primary_keys, foreign_keys, model_names =\
+        columns, primary_keys, foreign_keys, model_names, indexes =\
                 introspector.introspect()
 
         expected = (
             ('coltypes', (
-                ('f1', 'f1 = BigIntegerField()'),
+                ('f1', 'f1 = BigIntegerField(index=True)'),
                 #('f2', 'f2 = BlobField()'),
-                ('f4', 'f4 = CharField(max_length=50)'),
+                ('f4', 'f4 = CharField()'),
                 ('f5', 'f5 = DateField()'),
                 ('f6', 'f6 = DateTimeField()'),
                 ('f7', 'f7 = DecimalField()'),
-                ('f10', 'f10 = IntegerField()'),
+                ('f10', 'f10 = IntegerField(unique=True)'),
                 ('f11', 'f11 = PrimaryKeyField()'),
                 ('f12', 'f12 = TextField()'),
                 ('f13', 'f13 = TimeField()'),
             )),
             ('nullable', (
                 ('nullable_cf', 'nullable_cf = '
-                 'CharField(max_length=255, null=True)'),
+                 'CharField(null=True)'),
                 ('nullable_if', 'nullable_if = IntegerField(null=True)'),
             )),
             ('fkpk', (
@@ -378,10 +420,10 @@ class TestReflection(unittest.TestCase):
             )),
             ('underscores', (
                 ('_id', '_id = PrimaryKeyField()'),
-                ('_name', '_name = CharField(max_length=255)'),
+                ('_name', '_name = CharField()'),
             )),
             ('category', (
-                ('name', 'name = CharField(max_length=10)'),
+                ('name', 'name = CharField()'),
                 ('parent_id', 'parent = ForeignKeyField('
                  'db_column=\'parent_id\', null=True, rel_model=\'self\', '
                  'to_field=\'id\')'),
